Regards
-steve
Index: tools/corosync-keygen.c
===================================================================
--- tools/corosync-keygen.c	(revision 2050)
+++ tools/corosync-keygen.c	(working copy)
@@ -83,9 +83,13 @@
 		exit (1);
 	}
 	/*
 	 * Set security of authorization key to uid = 0 uid = 0 mode = 0400
 	 */
-	fchown (authkey_fd, 0, 0);
+	res = fchown (authkey_fd, 0, 0);
+	if (res == -1) {
+		perror ("Could not fchown key to uid 0 and gid 0\n");
+		exit (1);
+	}
 	fchmod (authkey_fd, 0400);
 
 	printf ("Writing corosync key to " KEYFILE ".\n");
@@ -83,9 +83,13 @@
 	}
 	/*
-	 * Set security of authorization key to uid = 0 uid = 0 mode = 0400
+	 * Set security of authorization key to uid = 0 gid = 0 mode = 0400
 	 */
_______________________________________________
Openais mailing list
Openais@lists.linux-foundation.org
https://lists.linux-foundation.org/mailman/listinfo/openais

Reply via email to